@@ -71,6 +71,10 @@ class NetboxConnection(object):
         if response.status_code == 204:
             return response.content
 
+        if(method == "GET" and ("&export=" in url or "?export=" in url)):
+            # return raw result if export template is specified
+            return {"results": response.text}
+
         try:
             response_data = response.json()
         except json.JSONDecodeError:
