@@ -6,6 +6,7 @@ import netbox.exceptions as exceptions
 import netbox.tenancy as tenancy
 import netbox.extras as extras
 import netbox.circuits as circuits
+import netbox.status as status
 
 
 class NetBox(object):
@@ -17,4 +18,5 @@ class NetBox(object):
         self.virtualization = virtualization.Virtualization(self.connection)
         self.tenancy = tenancy.Tenancy(self.connection)
         self.extras = extras.Extras(self.connection)
+        self.status = status.Status(self.connection)
         self.exceptions = exceptions
